pub enum StandardAccountComponent {
BasicWallet,
FungibleFaucet,
Authority,
Ownable2Step,
RoleBasedAccessControl,
AuthSingleSig,
AuthSingleSigAcl,
AuthMultisig,
AuthMultisigSmart,
AuthGuardedMultisig,
AuthNoAuth,
AuthNetworkAccount,
}Expand description
The enum holding the types of standard account components defined in the miden-standards
crate.
Variants
BasicWallet
FungibleFaucet
Authority
Ownable2Step
RoleBasedAccessControl
AuthSingleSig
AuthSingleSigAcl
AuthMultisig
AuthMultisigSmart
AuthGuardedMultisig
AuthNoAuth
AuthNetworkAccount
Implementations
Sourceimpl StandardAccountComponent
impl StandardAccountComponent
Sourcepub fn procedure_roots(&self) -> impl Iterator<Item = AccountProcedureRoot>
pub fn procedure_roots(&self) -> impl Iterator<Item = AccountProcedureRoot>
Returns the iterator over the AccountProcedureRoots of all procedures exported from
the component.
Sourcepub fn extract_standard_components(
procedures_set: &mut BTreeSet<AccountProcedureRoot>,
component_interface_vec: &mut Vec<AccountComponentInterface>,
)
pub fn extract_standard_components( procedures_set: &mut BTreeSet<AccountProcedureRoot>, component_interface_vec: &mut Vec<AccountComponentInterface>, )
Gets all standard components which could be constructed from the provided procedures map
and pushes them to the component_interface_vec.