pub struct AuthControlled { /* private fields */ }Expand description
An AccountComponent providing configurable mint-policy management for network faucets.
It reexports policy procedures from miden::standards::mint_policies and manager procedures
from miden::standards::mint_policies::policy_manager:
allow_allset_mint_policyget_mint_policy
Storage Layout
Self::active_policy_proc_root_slot: Procedure root of the active mint policy.Self::allowed_policy_proc_roots_slot: Set of allowed mint policy procedure roots.Self::policy_authority_slot: Policy authority mode (MintPolicyAuthority::AuthControlled= tx auth,MintPolicyAuthority::OwnerControlled= external owner).
Implementations
Sourceimpl AuthControlled
impl AuthControlled
Sourcepub const NAME: &'static str = "miden::standards::components::mint_policies::auth_controlled"
pub const NAME: &'static str = "miden::standards::components::mint_policies::auth_controlled"
The name of the component.
Sourcepub fn new(policy: AuthControlledInitConfig) -> AuthControlled
pub fn new(policy: AuthControlledInitConfig) -> AuthControlled
Creates a new AuthControlled component from the provided configuration.
Sourcepub fn allow_all() -> AuthControlled
pub fn allow_all() -> AuthControlled
Creates a new AuthControlled component with allow_all policy as
default.
Sourcepub fn active_policy_proc_root_slot() -> &'static StorageSlotName
pub fn active_policy_proc_root_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the active mint policy procedure root is stored.
Sourcepub fn allowed_policy_proc_roots_slot() -> &'static StorageSlotName
pub fn allowed_policy_proc_roots_slot() -> &'static StorageSlotName
Returns the StorageSlotName where allowed policy roots are stored.
Sourcepub fn active_policy_proc_root_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn active_policy_proc_root_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the active mint policy root.
Sourcepub fn allowed_policy_proc_roots_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn allowed_policy_proc_roots_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the allowed policy roots map.
Returns the StorageSlotName containing policy authority mode.
Returns the storage slot schema for policy authority mode.
Sourcepub fn allow_all_policy_root() -> Word
pub fn allow_all_policy_root() -> Word
Returns the default allow_all policy root.
Returns the policy authority used by this component.