pub struct AuthMultisigPsm { /* private fields */ }Expand description
An AccountComponent implementing a multisig authentication with a private state manager.
It enforces a threshold of approver signatures for every transaction, with optional per-procedure threshold overrides. With Private State Manager (PSM) is configured, multisig authorization is combined with PSM authorization, so operations require both multisig approval and a valid PSM signature. This substantially mitigates low-threshold state-withholding scenarios since the PSM is expected to forward state updates to other approvers.
This component supports all account types.
Implementations
Sourceimpl AuthMultisigPsm
impl AuthMultisigPsm
Sourcepub const NAME: &'static str = "miden::standards::components::auth::multisig_psm"
pub const NAME: &'static str = "miden::standards::components::auth::multisig_psm"
The name of the component.
Sourcepub fn new(
config: AuthMultisigPsmConfig,
) -> Result<AuthMultisigPsm, AccountError>
pub fn new( config: AuthMultisigPsmConfig, ) -> Result<AuthMultisigPsm, AccountError>
Creates a new AuthMultisigPsm component from the provided configuration.
Sourcepub fn threshold_config_slot() -> &'static StorageSlotName
pub fn threshold_config_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the threshold configuration is stored.
Sourcepub fn approver_public_keys_slot() -> &'static StorageSlotName
pub fn approver_public_keys_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the approver public keys are stored.
pub fn approver_scheme_ids_slot() -> &'static StorageSlotName
Sourcepub fn executed_transactions_slot() -> &'static StorageSlotName
pub fn executed_transactions_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the executed transactions are stored.
Sourcepub fn procedure_thresholds_slot() -> &'static StorageSlotName
pub fn procedure_thresholds_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the procedure thresholds are stored.
Sourcepub fn psm_public_key_slot() -> &'static StorageSlotName
pub fn psm_public_key_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the private state manager public key is stored.
Sourcepub fn psm_scheme_id_slot() -> &'static StorageSlotName
pub fn psm_scheme_id_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the private state manager scheme IDs are stored.
Sourcepub fn threshold_config_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn threshold_config_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the threshold configuration slot.
Sourcepub fn approver_public_keys_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn approver_public_keys_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the approver public keys slot.
pub fn approver_auth_scheme_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Sourcepub fn executed_transactions_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn executed_transactions_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the executed transactions slot.
Sourcepub fn procedure_thresholds_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn procedure_thresholds_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the procedure thresholds slot.
Sourcepub fn psm_public_key_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn psm_public_key_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the private state manager public key slot.
Sourcepub fn psm_auth_scheme_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn psm_auth_scheme_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the private state manager scheme IDs slot.
Sourcepub fn component_metadata() -> AccountComponentMetadata
pub fn component_metadata() -> AccountComponentMetadata
Returns the AccountComponentMetadata for this component.