pub struct BasicWallet;Expand description
An AccountComponent implementing a basic wallet.
It reexports the procedures from miden::standards::wallets::basic and
miden::standards::note::create_note modules. When linking against this component, the miden
library (i.e. ProtocolLib) must be available to the assembler
which is the case when using CodeBuilder. The procedures of this component are:
receive_asset, which can be used to add an asset to the account.move_asset_to_note, which can be used to remove the specified asset from the account and add it to the output note with the specified index.create_note, which can be used to create a new output note and return its index.
All methods require authentication. Thus, this component must be combined with a component providing authentication.
Implementations
Sourceimpl BasicWallet
impl BasicWallet
Sourcepub const NAME: &'static str = "miden::standards::wallets::basic_wallet"
pub const NAME: &'static str = "miden::standards::wallets::basic_wallet"
The name of the component.
Sourcepub const fn name() -> AccountComponentName
pub const fn name() -> AccountComponentName
Returns the canonical AccountComponentName of this component.
Sourcepub fn code() -> &'static AccountComponentCode
pub fn code() -> &'static AccountComponentCode
Returns the AccountComponentCode of this component.
Sourcepub fn receive_asset_root() -> AccountProcedureRoot
pub fn receive_asset_root() -> AccountProcedureRoot
Returns the procedure root of the receive_asset wallet procedure.
Sourcepub fn move_asset_to_note_root() -> AccountProcedureRoot
pub fn move_asset_to_note_root() -> AccountProcedureRoot
Returns the procedure root of the move_asset_to_note wallet procedure.
Sourcepub fn create_note_root() -> AccountProcedureRoot
pub fn create_note_root() -> AccountProcedureRoot
Returns the procedure root of the create_note wallet procedure.
Sourcepub fn component_metadata() -> AccountComponentMetadata
pub fn component_metadata() -> AccountComponentMetadata
Returns the AccountComponentMetadata for this component.