pub struct Pausable(/* private fields */);Expand description
Account component that installs the PausableStorage slot and exposes is_paused
view procedure.
Pair with PausableManager to expose pause / unpause admin procedures gated by the
account-wide crate::account::access::Authority component.
Implementations
Sourceimpl Pausable
impl Pausable
Sourcepub const NAME: &'static str = "miden::standards::components::access::pausable"
pub const NAME: &'static str = "miden::standards::components::access::pausable"
The name of the component.
pub const IS_PAUSED_PROC_NAME: &'static str = "is_paused"
Sourcepub const fn new(state: bool) -> Pausable
pub const fn new(state: bool) -> Pausable
Creates a Pausable component with the given pause state.
Sourcepub const fn paused() -> Pausable
pub const fn paused() -> Pausable
Creates a Pausable component that starts in the paused state.
Sourcepub const fn unpaused() -> Pausable
pub const fn unpaused() -> Pausable
Creates a Pausable component that starts in the unpaused state.
Sourcepub fn storage(&self) -> &PausableStorage
pub fn storage(&self) -> &PausableStorage
Returns the underlying PausableStorage helper.
Sourcepub fn code() -> &'static AccountComponentCode
pub fn code() -> &'static AccountComponentCode
Returns the AccountComponentCode of this component.
Sourcepub fn is_paused_root() -> AccountProcedureRoot
pub fn is_paused_root() -> AccountProcedureRoot
Returns the procedure root of the is_paused call procedure exposed by this component.