pub enum AccountComponentInterface {
Show 13 variants
BasicWallet,
FungibleFaucet,
Authority,
Ownable2Step,
RoleBasedAccessControl,
AuthSingleSig,
AuthSingleSigAcl,
AuthMultisig,
AuthMultisigSmart,
AuthGuardedMultisig,
AuthNoAuth,
AuthNetworkAccount,
Custom(Vec<AccountProcedureRoot>),
}Expand description
The enum holding all possible account interfaces which could be loaded to some account.
Variants
BasicWallet
Exposes procedures from the BasicWallet module.
FungibleFaucet
Exposes procedures from the
FungibleFaucet module.
Authority
Exposes procedures from the
Authority access component.
Ownable2Step
Exposes procedures from the
Ownable2Step access component.
RoleBasedAccessControl
Exposes procedures from the
RoleBasedAccessControl access
component.
AuthSingleSig
Exposes procedures from the
AuthSingleSig module.
AuthSingleSigAcl
Exposes procedures from the
AuthSingleSigAcl module.
AuthMultisig
Exposes procedures from the
AuthMultisig module.
AuthMultisigSmart
Exposes procedures from the
AuthMultisigSmart module.
AuthGuardedMultisig
Exposes procedures from the
AuthGuardedMultisig module.
AuthNoAuth
Exposes procedures from the NoAuth module.
This authentication scheme provides no cryptographic authentication and only increments the nonce if the account state has actually changed during transaction execution.
AuthNetworkAccount
Exposes procedures from the
AuthNetworkAccount module.
This authentication scheme is intended for network-owned accounts. It rejects transactions that executed a tx script or consumed input notes outside of a fixed allowlist of note script roots.
Custom(Vec<AccountProcedureRoot>)
A non-standard, custom interface which exposes the contained procedures.
Custom interface holds all procedures which are not part of some standard interface which is used by this account.
Implementations
Sourceimpl AccountComponentInterface
impl AccountComponentInterface
Sourcepub fn name(&self) -> String
pub fn name(&self) -> String
Returns a string line with the name of the AccountComponentInterface enum variant.
In case of a AccountComponentInterface::Custom along with the name of the enum variant
the vector of shortened hex representations of the used procedures is returned, e.g.
Custom([0x6d93447, 0x0bf23d8]).
Sourcepub fn is_auth_component(&self) -> bool
pub fn is_auth_component(&self) -> bool
Returns true if this component interface is an authentication component.
TODO: currently this can identify only standard auth components
Sourcepub fn get_auth_methods(&self, storage: &AccountStorage) -> Vec<AuthMethod>
pub fn get_auth_methods(&self, storage: &AccountStorage) -> Vec<AuthMethod>
Returns the authentication schemes associated with this component interface.