pub enum StorageMapPatch {
Create {
entries: StorageMapPatchEntries,
},
Update {
entries: StorageMapPatchEntries,
},
Remove,
}Expand description
The patch of a single map storage slot.
Variants
Create
Records the creation of the map with the given entries.
An empty entry set is meaningful to represent the creation of an empty map.
Fields
entries: StorageMapPatchEntriesUpdate
Records that the entries of an existing map were changed.
The entries should be non-empty, since empty entries are a no-op.
Fields
entries: StorageMapPatchEntriesRemove
Records that the map slot was removed.
Implementations
Sourceimpl StorageMapPatch
impl StorageMapPatch
Sourcepub fn entries(&self) -> Option<&StorageMapPatchEntries>
pub fn entries(&self) -> Option<&StorageMapPatchEntries>
Returns the entries of the map patch for StorageMapPatch::Create and
StorageMapPatch::Update, or None for StorageMapPatch::Remove.
Sourcepub fn into_entries(self) -> Option<StorageMapPatchEntries>
pub fn into_entries(self) -> Option<StorageMapPatchEntries>
Consumes self and returns the entries of the map patch for StorageMapPatch::Create and
StorageMapPatch::Update, or None for StorageMapPatch::Remove.
Sourcepub fn patch_op(&self) -> StoragePatchOperation
pub fn patch_op(&self) -> StoragePatchOperation
Returns the StoragePatchOperation that this patch represents.
Sourceimpl StorageMapPatch
impl StorageMapPatch
Sourcepub fn from_iters(
cleared_keys: impl IntoIterator<Item = StorageMapKey>,
updated_entries: impl IntoIterator<Item = (StorageMapKey, Word)>,
) -> StorageMapPatch
pub fn from_iters( cleared_keys: impl IntoIterator<Item = StorageMapKey>, updated_entries: impl IntoIterator<Item = (StorageMapKey, Word)>, ) -> StorageMapPatch
Creates a new StorageMapPatch::Update from the provided iterators of cleared and updated
entries.