pub struct AccountInterface { /* private fields */ }Expand description
An AccountInterface describes the exported, callable procedures of an account.
Implementations
Sourceimpl AccountInterface
Constructors and public accessors
impl AccountInterface
Constructors and public accessors
Sourcepub fn new(
account_id: AccountId,
components: Vec<AccountComponentInterface>,
) -> AccountInterface
pub fn new( account_id: AccountId, components: Vec<AccountComponentInterface>, ) -> AccountInterface
Creates a new AccountInterface instance from the provided account ID and account
component interfaces.
Panics
Panics if components does not contain exactly one auth component. Every account installs
a single auth component. Zero or multiple auth components is a malformed account.
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Returns true if the reference account is a private account, false otherwise.
Sourcepub fn is_public(&self) -> bool
pub fn is_public(&self) -> bool
Returns true if the reference account is a public account, false otherwise.
Sourcepub fn components(&self) -> &Vec<AccountComponentInterface>
pub fn components(&self) -> &Vec<AccountComponentInterface>
Returns a reference to the set of used component interfaces.
Sourcepub fn auth_component(&self) -> &AccountComponentInterface
pub fn auth_component(&self) -> &AccountComponentInterface
Returns a reference to the single auth component installed on this account.
Every account installs exactly one auth component (validated in Self::new).