AccountReader

Struct AccountReader 

pub struct AccountReader { /* private fields */ }
Provides lazy access to account data.

AccountReader executes queries lazily - each method call fetches fresh data from storage, ensuring you always see the current state.

Example

let reader = client.account_reader(account_id);

// Each call fetches fresh data
let nonce = reader.nonce().await?;
let status = reader.status().await?;
let commitment = reader.commitment().await?;

// Vault access
let balance = reader.get_balance(faucet_id).await?;

// Storage access
let value = reader.get_storage_item("my_slot").await?;

Implementations

Source

impl AccountReader

pub fn new(store: Arc<dyn Store>, account_id: AccountId) -> Self

Creates a new AccountReader for the given account.

pub fn account_id(&self) -> AccountId

Returns the account ID (fixed at construction).

pub async fn nonce(&self) -> Result<Felt, ClientError>

Retrieves the current account nonce.

pub async fn commitment(&self) -> Result<Word, ClientError>

Retrieves the account commitment (hash of the full state).

pub async fn storage_commitment(&self) -> Result<Word, ClientError>

Retrieves the storage commitment (root of the storage tree).

pub async fn vault_root(&self) -> Result<Word, ClientError>

Retrieves the vault root (root of the asset vault tree).

pub async fn code_commitment(&self) -> Result<Word, ClientError>

Retrieves the code commitment (hash of the account code).

pub async fn status(&self) -> Result<AccountStatus, ClientError>

Retrieves the current account status (New, Tracked, or Locked).

pub async fn header( &self, ) -> Result<(AccountHeader, AccountStatus), ClientError>

Retrieves the account header and status.

pub async fn addresses(&self) -> Result<Vec<Address>, ClientError>

Retrieves the addresses associated with this account.

pub async fn get_balance( &self, faucet_id: AccountId, ) -> Result<u64, ClientError>

Retrieves the balance of a fungible asset in the account’s vault.

Returns 0 if the asset is not present in the vault or if the asset is not a fungible asset.

To load the entire vault, use Client::get_account_vault.

pub async fn get_storage_item( &self, slot_name: impl Into<StorageSlotName>, ) -> Result<Word, ClientError>

Retrieves a storage slot value by name.

This method fetches the requested slot from storage.

For Value slots, returns the stored word. For Map slots, returns the map root.

pub async fn get_storage_map_item( &self, slot_name: impl Into<StorageSlotName>, key: StorageMapKey, ) -> Result<Word, ClientError>

Retrieves a value from a storage map slot by name and key.

This method fetches only the requested slot from storage.

Errors

Returns an error if the slot is not found or is not a map.

pub async fn get_storage_map_witness( &self, slot_name: impl Into<StorageSlotName>, key: StorageMapKey, ) -> Result<(Word, StorageMapWitness), ClientError>

Retrieves a value and its Merkle witness from a storage map slot.

This method fetches the requested slot from storage and it’s inclusion proof.

Errors

Returns an error if the slot is not found or is not a map.