pub struct AccountSchemaCommitment { /* private fields */ }Expand description
An AccountComponent exposing the account storage schema commitment.
The AccountSchemaCommitment component can be constructed from a list of StorageSchema,
from which a commitment is computed and then inserted into the slot returned by
AccountSchemaCommitment::schema_commitment_slot().
It reexports the get_schema_commitment procedure from
miden::standards::metadata::storage_schema.
Storage Layout
Self::schema_commitment_slot: Storage schema commitment.
Implementations
Sourceimpl AccountSchemaCommitment
impl AccountSchemaCommitment
Sourcepub fn new<'a>(
schemas: impl IntoIterator<Item = &'a StorageSchema>,
) -> Result<AccountSchemaCommitment, ComponentMetadataError>
pub fn new<'a>( schemas: impl IntoIterator<Item = &'a StorageSchema>, ) -> Result<AccountSchemaCommitment, ComponentMetadataError>
Creates a new AccountSchemaCommitment component from storage schemas.
The input schemas are merged into a single schema before the final commitment is computed.
Errors
Returns an error if the schemas contain conflicting definitions for the same slot name.
Sourcepub fn from_schema(
storage_schema: &StorageSchema,
) -> Result<AccountSchemaCommitment, ComponentMetadataError>
pub fn from_schema( storage_schema: &StorageSchema, ) -> Result<AccountSchemaCommitment, ComponentMetadataError>
Creates a new AccountSchemaCommitment component from a StorageSchema.
Sourcepub fn schema_commitment_slot() -> &'static StorageSlotName
pub fn schema_commitment_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the schema commitment is stored.
Sourcepub fn component_metadata() -> AccountComponentMetadata
pub fn component_metadata() -> AccountComponentMetadata
Returns the AccountComponentMetadata for this component.