pub struct FaucetMetadata {
pub symbol: String,
pub decimals: u8,
}Expand description
Display-only metadata for a faucet account, persisted in the client’s settings store.
Populated lazily by the CLI resolver from the on-chain token config of a public faucet
and persisted under a faucet_metadata:<faucet-id> key.
Fields
symbol: Stringdecimals: u8Trait Implementations
Sourceimpl Clone for FaucetMetadata
impl Clone for FaucetMetadata
Sourcefn clone(&self) -> FaucetMetadata
fn clone(&self) -> FaucetMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FaucetMetadata
impl Debug for FaucetMetadata
Sourceimpl Deserializable for FaucetMetadata
impl Deserializable for FaucetMetadata
Sourcefn read_from<R: ByteReader>(
source: &mut R,
) -> Result<Self, DeserializationError>
fn read_from<R: ByteReader>( source: &mut R, ) -> Result<Self, DeserializationError>
Reads a sequence of bytes from the provided
source, attempts to deserialize these bytes
into Self, and returns the result. Read moreSourcefn min_serialized_size() -> usize
fn min_serialized_size() -> usize
Returns the minimum serialized size for one instance of this type. Read more
Sourcefn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
fn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
Sourcefn read_from_bytes_with_budget(
bytes: &[u8],
budget: usize,
) -> Result<Self, DeserializationError>
fn read_from_bytes_with_budget( bytes: &[u8], budget: usize, ) -> Result<Self, DeserializationError>
Deserializes
Self from bytes with a byte budget limit. Read moreimpl Eq for FaucetMetadata
Sourceimpl PartialEq for FaucetMetadata
impl PartialEq for FaucetMetadata
Sourcefn eq(&self, other: &FaucetMetadata) -> bool
fn eq(&self, other: &FaucetMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serializable for FaucetMetadata
impl Serializable for FaucetMetadata
Sourcefn write_into<W: ByteWriter>(&self, target: &mut W)
fn write_into<W: ByteWriter>(&self, target: &mut W)
Serializes
self into bytes and writes these bytes into the target.Sourcefn get_size_hint(&self) -> usize
fn get_size_hint(&self) -> usize
Returns an estimate of how many bytes are needed to represent self. Read more
impl StructuralPartialEq for FaucetMetadata