Module errors

Module errors 

Constants

ERR_B2AGG_DESTINATION_NETWORK_IS_MIDEN
Error Message: “B2AGG note destination network ID must not be Miden’s AggLayer network ID”
ERR_B2AGG_NOTE_MUST_BE_PUBLIC
Error Message: “B2AGG note must be public”
ERR_B2AGG_TARGET_ACCOUNT_MISMATCH
Error Message: “B2AGG note attachment target account does not match consuming account”
ERR_B2AGG_UNEXPECTED_NUMBER_OF_STORAGE_ITEMS
Error Message: “B2AGG script expects exactly 6 note storage items”
ERR_B2AGG_WRONG_NUMBER_OF_ASSETS
Error Message: “B2AGG script requires exactly 1 note asset”
ERR_BRIDGE_NOT_MAINNET
Error Message: “mainnet flag must be 1 for a mainnet deposit”
ERR_BRIDGE_NOT_ROLLUP
Error Message: “mainnet flag must be 0 for a rollup deposit”
ERR_CLAIM_ALREADY_SPENT
Error Message: “claim note has already been spent”
ERR_CLAIM_LEAF_DESTINATION_NETWORK_MISMATCH
Error Message: “claim leaf destination network does not match Miden AggLayer network ID”
ERR_CLAIM_TARGET_ACCT_MISMATCH
Error Message: “CLAIM note attachment target account does not match consuming account”
ERR_CONFIG_AGG_BRIDGE_TARGET_ACCOUNT_MISMATCH
Error Message: “CONFIG_AGG_BRIDGE note attachment target account does not match consuming account”
ERR_CONFIG_AGG_BRIDGE_UNEXPECTED_STORAGE_ITEMS
Error Message: “CONFIG_AGG_BRIDGE expects exactly 18 note storage items”
ERR_FAUCET_NOT_REGISTERED
Error Message: “faucet is not registered in the bridge’s faucet registry”
ERR_FELT_OUT_OF_FIELD
Error Message: “combined u64 doesn’t fit in field”
ERR_GER_ALREADY_REGISTERED
Error Message: “GER is already registered in storage”
ERR_GER_NOT_FOUND
Error Message: “GER not found in storage”
ERR_INVALID_LEAF_TYPE
Error Message: “invalid leaf type: only asset claims (leafType=0) are supported”
ERR_LEADING_BITS_NON_ZERO
Error Message: “leading bits of global index must be zero”
ERR_MAINNET_FLAG_INVALID
Error Message: “mainnet flag must be 0 or 1”
ERR_MSB_NONZERO
Error Message: “most-significant 4 bytes must be zero for AccountId”
ERR_MTF_LEAVES_NUM_EXCEED_LIMIT
Error Message: “number of leaves in the MTF would exceed 4294967295 (2^32 - 1)”
ERR_NOT_U32
Error Message: “address limb is not u32”
ERR_REMAINDER_TOO_LARGE
Error Message: “remainder z must be < 10^s”
ERR_ROLLUP_INDEX_NON_ZERO
Error Message: “rollup index must be zero for a mainnet deposit”
ERR_SCALE_AMOUNT_EXCEEDED_LIMIT
Error Message: “maximum scaling factor is 18”
ERR_SENDER_NOT_BRIDGE_ADMIN
Error Message: “note sender is not the bridge admin”
ERR_SENDER_NOT_GER_MANAGER
Error Message: “note sender is not the global exit root manager”
ERR_SMT_ROOT_VERIFICATION_FAILED
Error Message: “merkle proof verification failed: provided SMT root does not match the computed root”
ERR_SOURCE_BRIDGE_NETWORK_OVERFLOW
Error Message: “source bridge network overflowed u32”
ERR_TOKEN_NOT_REGISTERED
Error Message: “(origin token address, origin network) pair is not registered in the bridge’s token registry”
ERR_UNDERFLOW
Error Message: “x < y*10^s (underflow detected)”
ERR_UPDATE_GER_TARGET_ACCOUNT_MISMATCH
Error Message: “UPDATE_GER note attachment target account does not match consuming account”
ERR_UPDATE_GER_UNEXPECTED_NUMBER_OF_STORAGE_ITEMS
Error Message: “UPDATE_GER script expects exactly 8 note storage items”
ERR_X_TOO_LARGE
Error Message: “the agglayer bridge in u256 value is larger than 2**128 and cannot be verifiably scaled to u64”
ERR_Y_TOO_LARGE
Error Message: “y exceeds max fungible token amount”