pub struct B2AggNote;Expand description
B2AGG (Bridge to AggLayer) note.
This note is used to bridge assets from Miden to another network via the AggLayer. When consumed by a bridge account, the assets are burned and a corresponding claim can be made on the destination network. B2AGG notes are always public.
Implementations
Sourceimpl B2AggNote
impl B2AggNote
Sourcepub const NUM_STORAGE_ITEMS: usize = 6
pub const NUM_STORAGE_ITEMS: usize = 6
Expected number of storage items for a B2AGG note.
Sourcepub fn script() -> NoteScript
pub fn script() -> NoteScript
Returns the B2AGG (Bridge to AggLayer) note script.
Sourcepub fn script_root() -> NoteScriptRoot
pub fn script_root() -> NoteScriptRoot
Returns the B2AGG note script root.
Sourcepub fn create<R>(
destination_network: u32,
destination_address: EthAddress,
assets: NoteAssets,
target_account_id: AccountId,
sender_account_id: AccountId,
rng: &mut R,
) -> Result<Note, NoteError>where
R: FeltRng,
pub fn create<R>(
destination_network: u32,
destination_address: EthAddress,
assets: NoteAssets,
target_account_id: AccountId,
sender_account_id: AccountId,
rng: &mut R,
) -> Result<Note, NoteError>where
R: FeltRng,
Creates a B2AGG (Bridge to AggLayer) note.
This note is used to bridge assets from Miden to another network via the AggLayer. When consumed by a bridge account, the assets are burned and a corresponding claim can be made on the destination network. B2AGG notes are always public.
Parameters
destination_network: The AggLayer-assigned network ID for the destination chaindestination_address: The Ethereum address on the destination networkassets: The assets to bridge (must be fungible assets from a network faucet)target_account_id: The account ID that will consume this note (bridge account)sender_account_id: The account ID of the note creatorrng: Random number generator for creating the note serial number
Errors
Returns an error if note creation fails.