#[repr(u8)]pub enum Signature {
Falcon512Poseidon2(Signature),
EcdsaK256Keccak(Signature),
}Expand description
Represents a signature object ready for native verification.
In order to use this signature within the Miden VM, an encoding step may be necessary to
convert the native signature into a vector of field elements that can be loaded into the advice
provider. To encode the signature, use the provided Signature::to_encoded_signature method:
use miden_protocol::account::auth::Signature;
use miden_protocol::crypto::dsa::falcon512_poseidon2::SecretKey;
use miden_protocol::{Felt, Word};
let secret_key = SecretKey::new();
let message = Word::default();
let signature: Signature = secret_key.sign(message).into();
let encoded_signature: Vec<Felt> = signature.to_encoded_signature(message);Variants
Implementations
Sourceimpl Signature
impl Signature
Sourcepub const MAX_NUM_ENCODED_SIGNATURE_FELTS: usize = 2058
pub const MAX_NUM_ENCODED_SIGNATURE_FELTS: usize = 2058
The maximum number of field elements that Signature::to_encoded_signature can return
for any variant.
This lets consumers reject an encoded signature of an impossible length before allocating
for it. The largest encoding is the one of Signature::Falcon512Poseidon2.
Sourcepub fn auth_scheme(&self) -> AuthScheme
pub fn auth_scheme(&self) -> AuthScheme
Returns the authentication scheme of this signature.
Sourcepub fn to_encoded_signature(&self, msg: Word) -> Vec<Felt>
pub fn to_encoded_signature(&self, msg: Word) -> Vec<Felt>
Converts this signature to a sequence of field elements in the format expected by the native verification procedure in the VM.
The returned vector contains at most Signature::MAX_NUM_ENCODED_SIGNATURE_FELTS
elements.
The order of elements in the returned vector is reversed because it is expected that the data will be pushed into the advice stack