pub enum SigningInputs {
TransactionSummary(Box<TransactionSummary>),
Arbitrary(Vec<BaseElement>),
Blind(Word),
}Expand description
Data types on which a signature can be requested.
It supports three modes:
TransactionSummary: Structured transaction summary, recommended for authenticating transactions.Arbitrary: Arbitrary payload provided by the application. It is up to the authenticator to display it appropriately.Blind: The underlying data is not meant to be displayed in a human-readable format. It must be a cryptographic commitment to some data.
Variants
Implementations
Sourceimpl SigningInputs
Convenience methods for SigningInputs.
impl SigningInputs
Convenience methods for SigningInputs.
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Computes the commitment to SigningInputs.
Sourcepub fn to_elements(&self) -> Vec<BaseElement>
pub fn to_elements(&self) -> Vec<BaseElement>
Returns a representation of the SigningInputs as a sequence of field elements.