pub struct AuthMultisig { /* private fields */ }Expand description
An AccountComponent implementing a multisig authentication.
It enforces a threshold of approver signatures for every transaction, with optional per-procedure threshold overrides. Non-uniform thresholds (especially a threshold of one) should be used with caution for private multisig accounts, without Private State Manager (PSM), a single approver may advance state and withhold updates from other approvers, effectively locking them out.
This component supports all account types.
Implementations
Sourceimpl AuthMultisig
impl AuthMultisig
Sourcepub const NAME: &'static str = "miden::standards::components::auth::multisig"
pub const NAME: &'static str = "miden::standards::components::auth::multisig"
The name of the component.
Sourcepub fn new(config: AuthMultisigConfig) -> Result<AuthMultisig, AccountError>
pub fn new(config: AuthMultisigConfig) -> Result<AuthMultisig, AccountError>
Creates a new AuthMultisig component from the provided configuration.
Sourcepub fn threshold_config_slot() -> &'static StorageSlotName
pub fn threshold_config_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the threshold configuration is stored.
Sourcepub fn approver_public_keys_slot() -> &'static StorageSlotName
pub fn approver_public_keys_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the approver public keys are stored.
pub fn approver_scheme_ids_slot() -> &'static StorageSlotName
Sourcepub fn executed_transactions_slot() -> &'static StorageSlotName
pub fn executed_transactions_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the executed transactions are stored.
Sourcepub fn procedure_thresholds_slot() -> &'static StorageSlotName
pub fn procedure_thresholds_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the procedure thresholds are stored.
Sourcepub fn threshold_config_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn threshold_config_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the threshold configuration slot.
Sourcepub fn approver_public_keys_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn approver_public_keys_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the approver public keys slot.
pub fn approver_auth_scheme_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Sourcepub fn executed_transactions_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn executed_transactions_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the executed transactions slot.
Sourcepub fn procedure_thresholds_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn procedure_thresholds_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the procedure thresholds slot.
Sourcepub fn component_metadata() -> AccountComponentMetadata
pub fn component_metadata() -> AccountComponentMetadata
Returns the AccountComponentMetadata for this component.