pub struct AuthSingleSig { /* private fields */ }Expand description
An AccountComponent implementing the signature scheme for authentication
of transactions.
This component exports auth_tx, which loads the public key and signature scheme id from
storage and delegates transaction authentication to
miden::standards::auth::signature::authenticate_transaction.
When linking against this component, the miden::standards library must be available to the
assembler (which also implies availability of miden::protocol). This is the case when using
CodeBuilder.
Implementations
Sourceimpl AuthSingleSig
impl AuthSingleSig
Sourcepub const NAME: &'static str = "miden::standards::components::auth::singlesig"
pub const NAME: &'static str = "miden::standards::components::auth::singlesig"
The name of the component.
Sourcepub const fn name() -> AccountComponentName
pub const fn name() -> AccountComponentName
Returns the canonical AccountComponentName of this component.
Sourcepub fn code() -> &'static AccountComponentCode
pub fn code() -> &'static AccountComponentCode
Returns the AccountComponentCode of this component.
Sourcepub fn new(
pub_key: PublicKeyCommitment,
auth_scheme: AuthScheme,
) -> AuthSingleSig
pub fn new( pub_key: PublicKeyCommitment, auth_scheme: AuthScheme, ) -> AuthSingleSig
Creates a new AuthSingleSig component with the given public_key.
Sourcepub fn falcon512_poseidon2(pub_key: PublicKey) -> AuthSingleSig
pub fn falcon512_poseidon2(pub_key: PublicKey) -> AuthSingleSig
Creates a new AuthSingleSig component using the Falcon512Poseidon2 signature scheme.
The public key commitment is derived from the provided Falcon512 public key.
Sourcepub fn ecdsa_k256_keccak(pub_key: PublicKey) -> AuthSingleSig
pub fn ecdsa_k256_keccak(pub_key: PublicKey) -> AuthSingleSig
Creates a new AuthSingleSig component using the EcdsaK256Keccak signature scheme.
The public key commitment is derived from the provided ECDSA K256 public key.
Sourcepub fn from_public_key(pub_key: PublicKey) -> AuthSingleSig
pub fn from_public_key(pub_key: PublicKey) -> AuthSingleSig
Creates a new AuthSingleSig component from a PublicKey.
The authentication scheme and public key commitment are derived from the provided key.
Sourcepub fn public_key_slot() -> &'static StorageSlotName
pub fn public_key_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the public key is stored.
pub fn scheme_id_slot() -> &'static StorageSlotName
Sourcepub fn public_key_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn public_key_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the public key slot.
Sourcepub fn auth_scheme_slot_schema() -> (StorageSlotName, StorageSlotSchema)
pub fn auth_scheme_slot_schema() -> (StorageSlotName, StorageSlotSchema)
Returns the storage slot schema for the scheme ID slot.
Sourcepub fn component_metadata() -> AccountComponentMetadata
pub fn component_metadata() -> AccountComponentMetadata
Returns the AccountComponentMetadata for this component.