BlockHeader

Struct BlockHeader 

pub struct BlockHeader { /* private fields */ }
The header of a block. It contains metadata about the block, commitments to the current state of the chain and the hash of the proof that attests to the integrity of the chain.

A block header includes the following fields:

  • version specifies the version of the protocol.
  • prev_block_commitment is the hash of the previous block header.
  • block_num is a unique sequential number of the current block.
  • chain_commitment is a commitment to an MMR of the entire chain where each block is a leaf.
  • account_root is a commitment to account database.
  • nullifier_root is a commitment to the nullifier database.
  • note_root is a commitment to all notes created in the current block.
  • tx_commitment is a commitment to the set of transaction IDs which affected accounts in the block.
  • tx_kernel_commitment a commitment to all transaction kernels supported by this block.
  • validator_key is the public key of the validator that is expected to sign the block.
  • fee_parameters are the parameters defining the base fees and the native asset, see FeeParameters for more details.
  • timestamp is the time when the block was created, in seconds since UNIX epoch. Current representation is sufficient to represent time up to year 2106.
  • sub_commitment is a sequential hash of all fields except the note_root.
  • commitment is a 2-to-1 hash of the sub_commitment and the note_root.

Implementations

Source

impl BlockHeader

pub fn new( version: u32, prev_block_commitment: Word, block_num: BlockNumber, chain_commitment: Word, account_root: Word, nullifier_root: Word, note_root: Word, tx_commitment: Word, tx_kernel_commitment: Word, validator_key: PublicKey, fee_parameters: FeeParameters, timestamp: u32, ) -> BlockHeader

Creates a new block header.

pub fn version(&self) -> u32

Returns the protocol version.

pub fn commitment(&self) -> Word

Returns the commitment of the block header.

pub fn sub_commitment(&self) -> Word

Returns the sub commitment of the block header.

The sub commitment is a sequential hash of all block header fields except the note root. This is used in the block commitment computation which is a 2-to-1 hash of the sub commitment and the note root [hash(sub_commitment, note_root)]. This procedure is used to make the note root easily accessible without having to unhash the entire header.

pub fn prev_block_commitment(&self) -> Word

Returns the commitment to the previous block header.

pub fn block_num(&self) -> BlockNumber

Returns the block number.

pub fn block_epoch(&self) -> u16

Returns the epoch to which this block belongs.

This is the block number shifted right by BlockNumber::EPOCH_LENGTH_EXPONENT.

pub fn chain_commitment(&self) -> Word

Returns the chain commitment.

pub fn account_root(&self) -> Word

Returns the account database root.

pub fn nullifier_root(&self) -> Word

Returns the nullifier database root.

pub fn note_root(&self) -> Word

Returns the note root.

pub fn validator_key(&self) -> &PublicKey

Returns the public key of the block’s validator.

pub fn tx_commitment(&self) -> Word

Returns the commitment to all transactions in this block.

The commitment is computed as sequential hash of (transaction_id, account_id) tuples. This makes it possible for the verifier to link transaction IDs to the accounts which they were executed against.

pub fn tx_kernel_commitment(&self) -> Word

Returns the transaction kernel commitment.

The transaction kernel commitment is computed as a sequential hash of all transaction kernel hashes.

pub fn fee_parameters(&self) -> &FeeParameters

Returns a reference to the FeeParameters in this header.

pub fn timestamp(&self) -> u32

Returns the timestamp at which the block was created, in seconds since UNIX epoch.

pub fn epoch_block_num(&self) -> BlockNumber

Returns the block number of the epoch block to which this block belongs.

Source

impl BlockHeader

pub fn mock( block_num: impl Into<BlockNumber>, chain_commitment: Option<Word>, note_root: Option<Word>, accounts: &[Account], tx_kernel_commitment: Word, ) -> BlockHeader

Creates a mock block. The account tree is formed from the provided accounts, and the chain commitment and note root are set to the provided chain_commitment and note_root values respectively.

For non-WASM targets, the remaining header values are initialized randomly. For WASM targets, values are initialized to Default::default()