Module builder

Module builder 

Available on crate feature std only.

Structs

ClientBuilder
A builder for constructing a Miden client.

Enums

StoreBuilder
Allows the ClientBuilder to accept either an already built store instance or a factory for deferring the store instantiation.

Traits

BuilderAuthenticator
Marker trait to capture the bounds the builder requires for the authenticator type parameter
StoreFactory
Trait for building a store instance.