pub struct ClientBuilder<AUTH> {
pub store: Option<StoreBuilder>,
/* private fields */
}Expand description
A builder for constructing a Miden client.
This builder allows you to configure the various components required by the client, such as the RPC endpoint, store, RNG, and authenticator. It is generic over the authenticator type.
Network-Aware Constructors
Use one of the network-specific constructors to get sensible defaults for a specific network:
for_testnet()- Pre-configured for Miden testnetfor_devnet()- Pre-configured for Miden devnetfor_localhost()- Pre-configured for local development
The builder provides defaults for:
- RPC endpoint: Automatically configured based on the network
- Transaction prover: Remote for testnet/devnet, local for localhost
- RNG: Random seed-based prover randomness
Components
The client requires several components to function:
-
RPC client (
NodeRpcClient): Provides connectivity to the Miden node for submitting transactions, syncing state, and fetching account/note data. Configure viarpc()orgrpc_client(). -
Store (
Store): Provides persistence for accounts, notes, and transaction history. Configure viastore(). -
RNG (
FeltRng): Provides randomness for generating keys, serial numbers, and other cryptographic operations. If not provided, a random seed-based RNG is created automatically. Configure viarng(). -
Authenticator (
TransactionAuthenticator): Handles transaction signing when signatures are requested from within the VM. Configure viaauthenticator(). -
Transaction prover (
TransactionProver): Generates proofs for transactions. Defaults to a local prover if not specified. Configure viaprover(). -
Note transport (
NoteTransportClient): Optional component for exchanging private notes through the Miden note transport network. Configure vianote_transport(). -
Debug mode: Enables debug mode for transaction execution. Configure via
in_debug_mode(). -
Transaction discard delta: Number of blocks after which pending transactions are considered stale and discarded. Configure via
tx_discard_delta(). -
Max block number delta: Maximum number of blocks the client can be behind the network for transactions and account proofs to be considered valid. Configure via
max_block_number_delta().
Fields
store: Option<StoreBuilder>An optional store provided by the user.
Implementations
Sourceimpl<AUTH> ClientBuilder<AUTH>where
AUTH: BuilderAuthenticator,
Network-specific constructors for ClientBuilder.
impl<AUTH> ClientBuilder<AUTH>where
AUTH: BuilderAuthenticator,
Network-specific constructors for ClientBuilder.
These constructors automatically configure the builder for a specific network, including RPC endpoint, transaction prover, and note transport (where applicable).
Sourcepub fn for_testnet() -> Self
Available on crate feature tonic only.
pub fn for_testnet() -> Self
tonic only.Creates a ClientBuilder pre-configured for Miden testnet.
This automatically configures:
- RPC:
Endpoint::testnet() - Prover: Remote prover at
TESTNET_PROVER_ENDPOINT - Note transport:
NOTE_TRANSPORT_TESTNET_ENDPOINT
You still need to provide:
- A store (via
.store()) - An authenticator (via
.authenticator())
All defaults can be overridden by calling the corresponding builder methods
after for_testnet().
Example
let client = ClientBuilder::for_testnet()
.store(store)
.authenticator(Arc::new(keystore))
.build()
.await?;Sourcepub fn for_devnet() -> Self
Available on crate feature tonic only.
pub fn for_devnet() -> Self
tonic only.Creates a ClientBuilder pre-configured for Miden devnet.
This automatically configures:
- RPC:
Endpoint::devnet() - Prover: Remote prover at
DEVNET_PROVER_ENDPOINT - Note transport:
NOTE_TRANSPORT_DEVNET_ENDPOINT
You still need to provide:
- A store (via
.store()) - An authenticator (via
.authenticator())
All defaults can be overridden by calling the corresponding builder methods
after for_devnet().
Example
let client = ClientBuilder::for_devnet()
.store(store)
.authenticator(Arc::new(keystore))
.build()
.await?;Sourcepub fn for_localhost() -> Self
Available on crate feature tonic only.
pub fn for_localhost() -> Self
tonic only.Creates a ClientBuilder pre-configured for localhost.
This automatically configures:
- RPC:
http://localhost:57291 - Prover: Local (default)
Note transport is not configured by default for localhost.
You still need to provide:
- A store (via
.store()) - An authenticator (via
.authenticator())
All defaults can be overridden by calling the corresponding builder methods
after for_localhost().
Example
let client = ClientBuilder::for_localhost()
.store(store)
.authenticator(Arc::new(keystore))
.build()
.await?;Sourceimpl<AUTH> ClientBuilder<AUTH>where
AUTH: BuilderAuthenticator,
impl<AUTH> ClientBuilder<AUTH>where
AUTH: BuilderAuthenticator,
Sourcepub fn in_debug_mode(self, debug: DebugMode) -> Self
pub fn in_debug_mode(self, debug: DebugMode) -> Self
Enable or disable debug mode.
Sourcepub fn rpc(self, client: Arc<dyn NodeRpcClient>) -> Self
pub fn rpc(self, client: Arc<dyn NodeRpcClient>) -> Self
Sets a custom RPC client directly.
Sourcepub fn grpc_client(self, endpoint: &Endpoint, timeout_ms: Option<u64>) -> Self
Available on crate feature tonic only.
pub fn grpc_client(self, endpoint: &Endpoint, timeout_ms: Option<u64>) -> Self
tonic only.Sets a gRPC client from the endpoint and optional timeout.
Sourcepub fn rng(self, rng: ClientRngBox) -> Self
pub fn rng(self, rng: ClientRngBox) -> Self
Optionally provide a custom RNG.
Sourcepub fn authenticator(self, authenticator: Arc<AUTH>) -> Self
pub fn authenticator(self, authenticator: Arc<AUTH>) -> Self
Optionally provide a custom authenticator instance.
Sourcepub fn max_block_number_delta(self, delta: u32) -> Self
pub fn max_block_number_delta(self, delta: u32) -> Self
Optionally set a maximum number of blocks that the client can be behind the network. By default, there’s no maximum.
Sourcepub fn tx_discard_delta(self, delta: Option<u32>) -> Self
pub fn tx_discard_delta(self, delta: Option<u32>) -> Self
Sets the number of blocks after which pending transactions are considered stale and discarded.
If a transaction has not been included in a block within this many blocks after submission,
it will be discarded. If None, transactions will be kept indefinitely.
By default, the delta is set to TX_DISCARD_DELTA (20 blocks).
Sourcepub fn tx_graceful_blocks(self, delta: Option<u32>) -> Self
👎Deprecated since 0.10.0: Use tx_discard_delta instead
pub fn tx_graceful_blocks(self, delta: Option<u32>) -> Self
Use tx_discard_delta instead
Sets the number of blocks after which pending transactions are considered stale and discarded.
This is an alias for tx_discard_delta.
Sourcepub fn note_transport(self, client: Arc<dyn NoteTransportClient>) -> Self
pub fn note_transport(self, client: Arc<dyn NoteTransportClient>) -> Self
Sets a custom note transport client directly.
Sourcepub fn prover(self, prover: Arc<dyn TransactionProver + Send + Sync>) -> Self
pub fn prover(self, prover: Arc<dyn TransactionProver + Send + Sync>) -> Self
Sets a custom transaction prover.
Sourcepub fn endpoint(&self) -> Option<&Endpoint>
pub fn endpoint(&self) -> Option<&Endpoint>
Returns the endpoint configured for this builder, if any.
This is set automatically when using network-specific constructors like
for_testnet(), for_devnet(),
or for_localhost().
Sourceimpl ClientBuilder<FilesystemKeyStore>
Convenience method for ClientBuilder when using FilesystemKeyStore as the authenticator.
impl ClientBuilder<FilesystemKeyStore>
Convenience method for ClientBuilder when using FilesystemKeyStore as the authenticator.
Sourcepub fn filesystem_keystore(
self,
keystore_path: impl Into<PathBuf>,
) -> Result<Self, ClientError>
Available on crate feature std only.
pub fn filesystem_keystore( self, keystore_path: impl Into<PathBuf>, ) -> Result<Self, ClientError>
std only.Creates a FilesystemKeyStore from the given path and sets it as the authenticator.
This is a convenience method that creates the keystore and configures it as the authenticator in a single call. The keystore provides transaction signing capabilities using keys stored on the filesystem.
Errors
Returns an error if the keystore cannot be created from the given path.
Example
let client = ClientBuilder::new()
.rpc(rpc_client)
.store(store)
.filesystem_keystore("path/to/keys")?
.build()
.await?;Trait Implementations