pub struct FilesystemKeyStore {
pub keys_directory: PathBuf,
/* private fields */
}std only.Expand description
A filesystem-based keystore that stores keys in separate files and provides transaction authentication functionality. The public key is hashed and the result is used as the filename and the contents of the file are the serialized public and secret key.
Account-to-key mappings are stored in a separate JSON index file.
Fields
keys_directory: PathBufThe directory where the keys are stored and read from.
Implementations
Sourceimpl FilesystemKeyStore
impl FilesystemKeyStore
Sourcepub fn new(keys_directory: PathBuf) -> Result<Self, KeyStoreError>
pub fn new(keys_directory: PathBuf) -> Result<Self, KeyStoreError>
Creates a FilesystemKeyStore on a specific directory.
Sourcepub fn get_key_sync(
&self,
pub_key: PublicKeyCommitment,
) -> Result<Option<AuthSecretKey>, KeyStoreError>
pub fn get_key_sync( &self, pub_key: PublicKeyCommitment, ) -> Result<Option<AuthSecretKey>, KeyStoreError>
Retrieves a secret key from the keystore given the commitment of a public key.