NetworkNoteExt

Trait NetworkNoteExt 

pub trait NetworkNoteExt {
    // Required methods
    fn is_network_note(&self) -> bool;
    fn into_account_target_network_note(
        self,
    ) -> Result<AccountTargetNetworkNote, NetworkAccountTargetError>;
}
Convenience helpers for Notes that may target a network account.

Required Methods

fn is_network_note(&self) -> bool

Returns true if this note is public and its attachment decodes as a NetworkAccountTarget.

fn into_account_target_network_note( self, ) -> Result<AccountTargetNetworkNote, NetworkAccountTargetError>

Consumes self and returns an AccountTargetNetworkNote, or an error if the attachment is not a valid target.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors