pub struct NoteConsumption {
pub nullifier: Nullifier,
pub block_num: BlockNumber,
pub external_consumer: Option<AccountId>,
}Expand description
A note consumption event observed on chain.
Fields
nullifier: NullifierThe nullifier of the consumed note.
block_num: BlockNumberThe block number at which the note consumption was registered on chain.
external_consumer: Option<AccountId>The account ID of the consumer of the note. Will be set if the note was consumed by a
transaction submitted outside this client by an account that is tracked locally.
Otherwise, it will be None.