pub struct Nullifier(/* private fields */);Expand description
A note’s nullifier.
A note’s nullifier is computed as:
hash(serial_num, script_root, input_commitment, asset_commitment).
This achieves the following properties:
- Every note can be reduced to a single unique nullifier.
- We cannot derive a note’s commitment from its nullifier, or a note’s nullifier from its hash.
- To compute the nullifier we must know all components of the note: serial_num, script_root, input_commitment and asset_commitment.
Implementations
Sourceimpl Nullifier
impl Nullifier
Sourcepub fn from_raw(word: Word) -> Nullifier
pub fn from_raw(word: Word) -> Nullifier
Construct without further checks from a given Word
Warning
This requires the caller to uphold the guarantees/invariants of this type (if any). Check the type-level documentation for guarantees/invariants.
Sourcepub fn as_elements(&self) -> &[BaseElement]
pub fn as_elements(&self) -> &[BaseElement]
Returns the elements representation of this value.
Sourceimpl Nullifier
impl Nullifier
Sourcepub fn new(
script_root: Word,
inputs_commitment: Word,
asset_commitment: Word,
serial_num: Word,
) -> Nullifier
pub fn new( script_root: Word, inputs_commitment: Word, asset_commitment: Word, serial_num: Word, ) -> Nullifier
Returns a new note Nullifier instantiated from the provided digest.
Sourcepub fn most_significant_felt(&self) -> BaseElement
pub fn most_significant_felt(&self) -> BaseElement
Returns the most significant felt (the last element in array)
Sourcepub fn prefix(&self) -> u16
pub fn prefix(&self) -> u16
Returns the prefix of this nullifier.
Nullifier prefix is defined as the 16 most significant bits of the nullifier value.
Sourcepub fn from_hex(hex_value: &str) -> Result<Nullifier, WordError>
pub fn from_hex(hex_value: &str) -> Result<Nullifier, WordError>
Creates a Nullifier from a hex string. Assumes that the string starts with “0x” and that the hexadecimal characters are big-endian encoded.
Callers must ensure the provided value is an actual Nullifier.
pub fn dummy(n: u64) -> Nullifier
testing only.Trait Implementations
Sourceimpl Deserializable for Nullifier
impl Deserializable for Nullifier
Sourcefn read_from<R>(source: &mut R) -> Result<Nullifier, DeserializationError>where
R: ByteReader,
fn read_from<R>(source: &mut R) -> Result<Nullifier, DeserializationError>where
R: ByteReader,
source, attempts to deserialize these bytes
into Self, and returns the result. Read moreSourcefn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
fn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
Sourceimpl From<&NoteDetails> for Nullifier
impl From<&NoteDetails> for Nullifier
Sourcefn from(note: &NoteDetails) -> Nullifier
fn from(note: &NoteDetails) -> Nullifier
Sourceimpl Ord for Nullifier
impl Ord for Nullifier
Sourceimpl PartialOrd for Nullifier
impl PartialOrd for Nullifier
Sourceimpl Serializable for Nullifier
impl Serializable for Nullifier
Sourcefn write_into<W>(&self, target: &mut W)where
W: ByteWriter,
fn write_into<W>(&self, target: &mut W)where
W: ByteWriter,
self into bytes and writes these bytes into the target.Sourcefn get_size_hint(&self) -> usize
fn get_size_hint(&self) -> usize
impl Copy for Nullifier
impl Eq for Nullifier
impl StructuralPartialEq for Nullifier