P2idNote

Struct P2idNote 

pub struct P2idNote;
TODO: add docs

Implementations

Source

impl P2idNote

pub const NUM_STORAGE_ITEMS: usize = P2idNoteStorage::NUM_ITEMS

Expected number of storage items of the P2ID note.

pub fn script() -> NoteScript

Returns the script of the P2ID (Pay-to-ID) note.

pub fn script_root() -> Word

Returns the P2ID (Pay-to-ID) note script root.

pub fn create<R>( sender: AccountId, target: AccountId, assets: Vec<Asset>, note_type: NoteType, attachment: NoteAttachment, rng: &mut R, ) -> Result<Note, NoteError>
where R: FeltRng,

Generates a P2ID note - Pay-to-ID note.

This script enables the transfer of assets from the sender account to the target account by specifying the target’s account ID.

The passed-in rng is used to generate a serial number for the note. The returned note’s tag is set to the target’s account ID.

Errors

Returns an error if deserialization or compilation of the P2ID script fails.