pub struct P2idNoteStorage { /* private fields */ }Expand description
Canonical storage representation for a P2ID note.
Contains the identifier of the target account that is authorized to consume the note. Only the account matching this ID can execute the note and claim its assets.
Implementations
Sourceimpl P2idNoteStorage
impl P2idNoteStorage
Sourcepub fn new(target: AccountId) -> P2idNoteStorage
pub fn new(target: AccountId) -> P2idNoteStorage
Creates new P2ID note storage targeting the given account.
Sourcepub fn into_recipient(self, serial_num: Word) -> NoteRecipient
pub fn into_recipient(self, serial_num: Word) -> NoteRecipient
Consumes the storage and returns a P2ID NoteRecipient with the provided serial number.
Notes created with this recipient will be P2ID notes consumable by the specified target
account stored in this P2idNoteStorage.