NoteConsumability

Type Alias NoteConsumability 

pub type NoteConsumability = (AccountId, NoteConsumptionStatus);
Represents the consumability of a note by a specific account.

The tuple contains the account ID that may consume the note and the moment it will become relevant.