pub struct GrpcNoteTransportClient { /* private fields */ }tonic only.Expand description
gRPC client for the note transport network.
The connection is established lazily on first use.
Implementations
Sourceimpl GrpcNoteTransportClient
impl GrpcNoteTransportClient
Sourcepub fn new(endpoint: String, timeout_ms: u64) -> Self
pub fn new(endpoint: String, timeout_ms: u64) -> Self
Creates a new GrpcNoteTransportClient without establishing a connection.
The connection will be established lazily on the first request.
Sourcepub async fn send_note(
&self,
header: NoteHeader,
details: Vec<u8>,
) -> Result<(), NoteTransportError>
pub async fn send_note( &self, header: NoteHeader, details: Vec<u8>, ) -> Result<(), NoteTransportError>
Pushes a note to the note transport network.
While the note header goes in plaintext, the provided note details can be encrypted.
Sourcepub async fn fetch_notes(
&self,
tags: &[NoteTag],
cursor: NoteTransportCursor,
) -> Result<(Vec<NoteInfo>, NoteTransportCursor), NoteTransportError>
pub async fn fetch_notes( &self, tags: &[NoteTag], cursor: NoteTransportCursor, ) -> Result<(Vec<NoteInfo>, NoteTransportCursor), NoteTransportError>
Downloads notes for given tags from the note transport network.
Returns notes labeled after the provided cursor (pagination), and an updated cursor.
Sourcepub async fn stream_notes(
&self,
tag: NoteTag,
cursor: NoteTransportCursor,
) -> Result<NoteStreamAdapter, NoteTransportError>
pub async fn stream_notes( &self, tag: NoteTag, cursor: NoteTransportCursor, ) -> Result<NoteStreamAdapter, NoteTransportError>
Stream notes from the note transport network.
Subscribes to a given tag. New notes are received periodically.
Sourcepub async fn health_check(&mut self) -> Result<(), NoteTransportError>
pub async fn health_check(&mut self) -> Result<(), NoteTransportError>
gRPC-standardized server health-check.
Checks if the note transport node and respective gRPC services are serving requests.
Currently the grPC server operates only one service labelled MidenNoteTransport.