pub struct TransportNote { /* private fields */ }Expand description
The part of a note that the note transport network sends to a recipient.
The transport sends the original header and details. It does not send note attachments. The constructor verifies that the header commits to the details.
Implementations
Sourceimpl TransportNote
impl TransportNote
Sourcepub fn new(
header: NoteHeader,
details: NoteDetails,
) -> Result<Self, NoteTransportError>
pub fn new( header: NoteHeader, details: NoteDetails, ) -> Result<Self, NoteTransportError>
Creates a transport note from matching note parts.
Sourcepub fn header(&self) -> &NoteHeader
pub fn header(&self) -> &NoteHeader
Returns the note header.
Sourcepub fn details(&self) -> &NoteDetails
pub fn details(&self) -> &NoteDetails
Returns the note details.
Sourcepub fn into_parts(self) -> (NoteHeader, NoteDetails)
pub fn into_parts(self) -> (NoteHeader, NoteDetails)
Returns the note header and details.