pub struct BlockHeader {
pub version: u32,
pub prev_block_commitment: Option<Digest>,
pub block_num: u32,
pub chain_commitment: Option<Digest>,
pub account_root: Option<Digest>,
pub nullifier_root: Option<Digest>,
pub note_root: Option<Digest>,
pub tx_commitment: Option<Digest>,
pub validator_key: Option<ValidatorPublicKey>,
pub tx_kernel_commitment: Option<Digest>,
pub fee_parameters: Option<FeeParameters>,
pub timestamp: u32,
}Available on crate features
testing and std only.Expand description
Represents a block header.
Fields
version: u32Specifies the version of the protocol.
prev_block_commitment: Option<Digest>The commitment of the previous blocks header.
block_num: u32A unique sequential number of the current block.
chain_commitment: Option<Digest>A commitment to an MMR of the entire chain where each block is a leaf.
account_root: Option<Digest>A commitment to account database.
nullifier_root: Option<Digest>A commitment to the nullifier database.
note_root: Option<Digest>A commitment to all notes created in the current block.
tx_commitment: Option<Digest>A commitment to a set of IDs of transactions which affected accounts in this block.
validator_key: Option<ValidatorPublicKey>The validator’s ECDSA public key.
tx_kernel_commitment: Option<Digest>A commitment to all transaction kernels supported by this block.
fee_parameters: Option<FeeParameters>Fee parameters for block processing.
timestamp: u32The time when the block was created.