pub struct SparseMerklePath {
pub empty_nodes_mask: u64,
pub siblings: Vec<Digest>,
}Available on crate features
testing and std only.Expand description
A different representation of a Merkle path designed for memory efficiency.
Fields
empty_nodes_mask: u64A bitmask representing empty nodes.
The set bit corresponds to the depth of an empty node. The least significant bit (bit 0)
describes depth 1 node (root’s children). The bit index + 1 is equal to node’s depth.
siblings: Vec<Digest>The non-empty nodes, stored in depth-order, but not contiguous across depth.