pub struct SyncNotesResponse {
pub pagination_info: Option<PaginationInfo>,
pub block_header: Option<BlockHeader>,
pub mmr_path: Option<MerklePath>,
pub notes: Vec<NoteSyncRecord>,
}Available on crate features
testing and std only.Expand description
Represents the result of syncing notes request.
Fields
pagination_info: Option<PaginationInfo>Pagination information.
block_header: Option<BlockHeader>Block header of the block with the first note matching the specified criteria.
mmr_path: Option<MerklePath>Merkle path to verify the block’s inclusion in the MMR at the returned chain_tip.
An MMR proof can be constructed for the leaf of index block_header.block_num of
an MMR of forest chain_tip with this path.
notes: Vec<NoteSyncRecord>List of all notes together with the Merkle paths from response.block_header.note_root.