Module shared

Module shared 

Available on crate features testing and std only.

Structs

BlockHeaderByNumberRequest
Returns the block header corresponding to the requested block number, as well as the merkle path and current forest which validate the block’s inclusion in the chain.
BlockHeaderByNumberResponse
Represents the result of getting a block header by block number.
MaybeNoteScript
Represents a note script or nothing.