pub struct TransactionHeader {
pub account_id: Option<AccountId>,
pub initial_state_commitment: Option<Digest>,
pub final_state_commitment: Option<Digest>,
pub nullifiers: Vec<Digest>,
pub output_notes: Vec<NoteSyncRecord>,
}Available on crate features
testing and std only.Expand description
Represents a transaction header.
Fields
account_id: Option<AccountId>ID of the account against which the transaction was executed.
initial_state_commitment: Option<Digest>State commitment of the account before the transaction was executed.
final_state_commitment: Option<Digest>State commitment of the account after the transaction was executed.
nullifiers: Vec<Digest>Nullifiers of the input notes of the transaction.
output_notes: Vec<NoteSyncRecord>Output notes of the transaction.