pub enum CheckNullifiersError {
Internal,
DeserializationFailed,
Unknown {
code: u8,
message: String,
},
}Variants
Internal
Internal server error (code 0)
DeserializationFailed
Failed to deserialize data
Unknown
Error code not recognized by this client version. This can happen if the node is newer than the client and has added new error variants.
Implementations