pub enum GetAccountError {
Internal,
DeserializationFailed,
AccountNotFound,
AccountNotPublic,
UnknownBlock,
BlockPruned,
Unknown {
code: u8,
message: String,
},
}Variants
Internal
Internal server error (code 0)
DeserializationFailed
Failed to deserialize data
AccountNotFound
Account was not found at the requested block
AccountNotPublic
Account is not public
UnknownBlock
Requested block number is unknown
BlockPruned
Requested block has been pruned
Unknown
Error code not recognized by this client version. This can happen if the node is newer than the client and has added new error variants.
Implementations