pub fn parse_status_error(
endpoint: &RpcEndpoint,
error_kind: &GrpcError,
message: &str,
) -> Option<EndpointError>Expand description
Parses the gRPC status code into a typed error for the given endpoint.
pub fn parse_status_error(
endpoint: &RpcEndpoint,
error_kind: &GrpcError,
message: &str,
) -> Option<EndpointError>Parses the gRPC status code into a typed error for the given endpoint.