pub struct AccountRecord { /* private fields */ }Expand description
Represents a stored account state along with its status.
The account should be stored in the database with its parts normalized. Meaning that the account header, vault, storage and code are stored separately. This is done to avoid data duplication as the header can reference the same elements if they have equal roots.
Implementations
Sourceimpl AccountRecord
impl AccountRecord
pub fn new( account_data: AccountRecordData, status: AccountStatus, addresses: Vec<Address>, ) -> Self
pub fn id(&self) -> AccountId
pub fn account_data(&self) -> &AccountRecordData
pub fn status(&self) -> &AccountStatus
pub fn is_locked(&self) -> bool
pub fn seed(&self) -> Option<Word>
pub fn nonce(&self) -> Felt
pub fn commitment(&self) -> Word
pub fn addresses(&self) -> &Vec<Address>
pub fn code(&self) -> AccountCode