pub struct StateSync { /* private fields */ }Expand description
The state sync component encompasses the client’s sync logic. It is then used to request updates from the node and apply them to the relevant elements. The updates are then returned and can be applied to the store to persist the changes.
Implementations
Sourceimpl StateSync
impl StateSync
Sourcepub fn new(
rpc_api: Arc<dyn NodeRpcClient>,
store: Option<Arc<dyn Store>>,
note_screener: Arc<dyn OnNoteReceived>,
tx_discard_delta: Option<u32>,
) -> Self
pub fn new( rpc_api: Arc<dyn NodeRpcClient>, store: Option<Arc<dyn Store>>, note_screener: Arc<dyn OnNoteReceived>, tx_discard_delta: Option<u32>, ) -> Self
Creates a new instance of the state sync component.
The nullifiers sync is enabled by default. To disable it, see
Self::disable_nullifier_sync.
Arguments
rpc_api- The RPC client used to communicate with the node.store- Optional store for on-demand account data access during delta sync.note_screener- The note screener used to check the relevance of notes.tx_discard_delta- Number of blocks after which pending transactions are discarded.
Sourcepub fn disable_nullifier_sync(&mut self)
pub fn disable_nullifier_sync(&mut self)
Disables the nullifier sync.
When disabled, the component will not query the node for new nullifiers after each sync step. This is useful for clients that don’t need to track note consumption, such as faucets.
Sourcepub fn enable_nullifier_sync(&mut self)
pub fn enable_nullifier_sync(&mut self)
Enables the nullifier sync.
Sourcepub async fn sync_state(
&self,
current_partial_mmr: &mut PartialMmr,
input: StateSyncInput,
) -> Result<StateSyncUpdate, ClientError>
pub async fn sync_state( &self, current_partial_mmr: &mut PartialMmr, input: StateSyncInput, ) -> Result<StateSyncUpdate, ClientError>
Syncs the state of the client with the chain tip of the node, returning the updates that should be applied to the store.
Use Client::build_sync_input() to build the default
input, or assemble it manually for custom sync. The current_partial_mmr is taken by
mutable reference so callers can keep it in memory across syncs.
During the sync process, the following steps are performed:
- A request is sent to the node to get the state updates. This request includes tracked account IDs and the tags of notes that might have changed or that might be of interest to the client.
- A response is received with the current state of the network. The response includes information about new and committed notes, updated accounts, and committed transactions.
- Tracked public accounts are updated and private accounts are validated against the node state.
- Tracked notes are updated with their new states. Notes might be committed or nullified during the sync processing.
- New notes are checked, and only relevant ones are stored. Relevance is determined by the
OnNoteReceivedcallback. - Transactions are updated with their new states. Transactions might be committed or discarded.
- The MMR is updated with the new peaks and authentication nodes.