Type Alias OnNoteReceived

pub type OnNoteReceived<'a> = Box<dyn Fn(CommittedNote, Option<InputNoteRecord>, Arc<NoteScreener<'a>>) -> Pin<Box<dyn Future<Output = Result<bool, ClientError>> + 'a>>>;
Callback that gets executed when a new note is received as part of the sync response.

It receives the committed note received from the network and an optional note record that corresponds to the state of the note in the network (only if the note is public).

It returns a boolean indicating if the received note update is relevant. If the return value is false, it gets discarded. If it is true, the update gets committed to the client’s store.

Aliased Type

pub struct OnNoteReceived<'a>(/* private fields */);