Available on crate feature
testing only.Expand description
Provides test utilities for working with accounts and account IDs
within the Miden network. This module is only available when the testing feature is
enabled.
Modules
- account_
component - account_
id - account_
interface - common
std - executor
- mock
- mock_
account - mock_
account_ code - note
- note_
transport - utils
Macros
Structs
- Mock
Chain - The
MockChainsimulates a simplified blockchain environment for testing purposes. - Mock
Chain Builder - A builder for a
MockChain’s genesis block. - Note
Builder - Transaction
Context - Represents all needed data for executing a transaction, or arbitrary code.
- Transaction
Context Builder - TransactionContextBuilder is a utility to construct TransactionContext for testing purposes. It allows users to build accounts, create notes, provide advice inputs, and execute code. The VM process can be inspected afterward.
Enums
- Account
State - Helper type for increased readability at call-sites. Indicates whether to build a new (nonce = ZERO) or existing account (nonce = ONE).
- Auth
- Specifies which authentication mechanism is desired for accounts
- Mock
Chain Note - Represents a note that is stored in the mock chain.
- TxContext
Input - Helper type to abstract over the inputs to
MockChain::build_tx_context. See that method’s docs for details.