pub struct AccountSetup { /* private fields */ }Available on crate features
std and testing only.Expand description
Configuration for an account inserted through TestClient::insert_account.
Implementations
Sourceimpl AccountSetup
impl AccountSetup
Sourcepub fn wallet(account_type: AccountType) -> Self
pub fn wallet(account_type: AccountType) -> Self
A basic wallet account.
Sourcepub fn faucet(account_type: AccountType) -> Self
pub fn faucet(account_type: AccountType) -> Self
A fungible faucet account.
Sourcepub fn prebuilt(account: Account, key: AuthSecretKey) -> Self
pub fn prebuilt(account: Account, key: AuthSecretKey) -> Self
An account the caller built, with the key its auth component commits to.
Sourcepub fn auth_scheme(self, auth_scheme: AuthSchemeId) -> Self
pub fn auth_scheme(self, auth_scheme: AuthSchemeId) -> Self
Signs with auth_scheme instead of the default ECDSA_K256_KECCAK_SCHEME_ID.
Sourcepub fn invitation_code(self, invitation_code: &str) -> Self
pub fn invitation_code(self, invitation_code: &str) -> Self
Registers the account on the network allowlist with invitation_code when it is inserted.