pub struct NoteBuilder { /* private fields */ }Available on crate feature
testing only.Implementations
Sourceimpl NoteBuilder
impl NoteBuilder
pub fn new<T>(sender: AccountId, rng: T) -> NoteBuilderwhere
T: Rng,
Sourcepub fn note_inputs(
self,
inputs: impl IntoIterator<Item = BaseElement>,
) -> Result<NoteBuilder, NoteError>
pub fn note_inputs( self, inputs: impl IntoIterator<Item = BaseElement>, ) -> Result<NoteBuilder, NoteError>
Set the note’s input to inputs.
Note: This overwrite the inputs, the previous input values are discarded.
pub fn add_assets(self, assets: impl IntoIterator<Item = Asset>) -> NoteBuilder
pub fn tag(self, tag: u32) -> NoteBuilder
pub fn note_type(self, note_type: NoteType) -> NoteBuilder
pub fn code<S>(self, code: S) -> NoteBuilder
Sourcepub fn serial_number(self, serial_number: Word) -> NoteBuilder
pub fn serial_number(self, serial_number: Word) -> NoteBuilder
Overwrites the generated serial number with a custom one.
Sourcepub fn attachment(self, attachment: impl Into<NoteAttachment>) -> NoteBuilder
pub fn attachment(self, attachment: impl Into<NoteAttachment>) -> NoteBuilder
Overwrites the attachment.
Sourcepub fn dynamically_linked_libraries(
self,
dyn_libraries: impl IntoIterator<Item = Library>,
) -> NoteBuilder
pub fn dynamically_linked_libraries( self, dyn_libraries: impl IntoIterator<Item = Library>, ) -> NoteBuilder
Extends the set of dynamically linked libraries that are passed to the assembler at build-time.
pub fn source_manager( self, source_manager: Arc<dyn SourceManagerSync>, ) -> NoteBuilder
pub fn build(self) -> Result<Note, NoteError>