TransactionContextBuilder

Struct TransactionContextBuilder 

pub struct TransactionContextBuilder { /* private fields */ }
Available on crate feature testing only.
TransactionContextBuilder is a utility to construct TransactionContext for testing purposes. It allows users to build accounts, create notes, provide advice inputs, and execute code. The VM process can be inspected afterward.

Examples

Create a new account and execute code:

let tx_context = TransactionContextBuilder::with_existing_mock_account().build()?;

let code = "
use $kernel::prologue
use mock::account

begin
    exec.prologue::prepare_transaction
    push.5
    swap drop
end
";

let exec_output = tx_context.execute_code(code).await?;
assert_eq!(exec_output.stack.get(0).unwrap(), &Felt::new(5));

Implementations

Source

impl TransactionContextBuilder

pub fn new(account: Account) -> TransactionContextBuilder

pub fn with_existing_mock_account() -> TransactionContextBuilder

Initializes a TransactionContextBuilder with a mock account.

The wallet:

pub fn with_noop_auth_account() -> TransactionContextBuilder

pub fn with_fungible_faucet( acct_id: u128, initial_balance: BaseElement, ) -> TransactionContextBuilder

Initializes a TransactionContextBuilder with a mocked fungible faucet.

pub fn with_non_fungible_faucet(acct_id: u128) -> TransactionContextBuilder

Initializes a TransactionContextBuilder with a mocked non-fungible faucet.

pub fn extend_advice_inputs( self, advice_inputs: AdviceInputs, ) -> TransactionContextBuilder

Extend the advice inputs with the provided AdviceInputs instance.

pub fn extend_advice_map( self, map_entries: impl IntoIterator<Item = (Word, Vec<BaseElement>)>, ) -> TransactionContextBuilder

Extend the advice inputs map with the provided iterator.

pub fn authenticator( self, authenticator: Option<BasicAuthenticator>, ) -> TransactionContextBuilder

Set the authenticator for the transaction (if needed)

pub fn foreign_accounts( self, inputs: impl IntoIterator<Item = (Account, AccountWitness)>, ) -> TransactionContextBuilder

Set foreign account codes that are used by the transaction

pub fn extend_input_notes( self, input_notes: Vec<Note>, ) -> TransactionContextBuilder

Extend the set of used input notes

pub fn tx_script( self, tx_script: TransactionScript, ) -> TransactionContextBuilder

Set the desired transaction script

pub fn tx_script_args(self, tx_script_args: Word) -> TransactionContextBuilder

Set the transaction script arguments

pub fn auth_args(self, auth_args: Word) -> TransactionContextBuilder

Set the desired auth arguments

pub fn tx_inputs( self, tx_inputs: TransactionInputs, ) -> TransactionContextBuilder

Set the desired transaction inputs

pub fn disable_lazy_loading(self) -> TransactionContextBuilder

Disables lazy loading.

Only affects TransactionContext::execute_code and causes the host to not handle lazy loading events.

pub fn disable_debug_mode(self) -> TransactionContextBuilder

Disables debug mode.

For performance-sensitive applications, debug mode should be disabled because executing in debug mode may be up to 100x slower.

pub fn extend_note_args( self, note_args: BTreeMap<NoteId, Word>, ) -> TransactionContextBuilder

Extend the note arguments map with the provided one.

pub fn extend_expected_output_notes( self, output_notes: Vec<OutputNote>, ) -> TransactionContextBuilder

Extend the expected output notes.

pub fn with_source_manager( self, source_manager: Arc<dyn SourceManagerSync>, ) -> TransactionContextBuilder

Sets the SourceManagerSync on the TransactionContext that will be built.

This source manager should contain the sources of all involved scripts and account code in order to provide better error messages if an error occurs.

pub fn add_signature( self, pub_key: PublicKeyCommitment, message: Word, signature: Signature, ) -> TransactionContextBuilder

Add a new signature for the message and the public key.

pub fn add_note_script(self, script: NoteScript) -> TransactionContextBuilder

Add a note script to the context for testing.

pub fn build(self) -> Result<TransactionContext, Error>

Builds the TransactionContext.

If no transaction inputs were provided manually, an ad-hoc MockChain is created in order to generate valid block data for the required notes.