create_spawn_note

Function create_spawn_note 

pub fn create_spawn_note<'note, I>(
    output_notes: impl IntoIterator<Item = &'note Note, IntoIter = I>,
) -> Result<Note, Error>
where I: ExactSizeIterator<Item = &'note Note>,
Available on crate feature testing only.
Creates a SPAWN note.

A SPAWN note contains a note script that creates all output_notes that get passed as a parameter.

Errors

Returns an error if:

  • the sender account ID of the provided output notes is not consistent or does not match the transaction’s sender.