pub struct PaymentNoteDescription { /* private fields */ }Expand description
Contains information needed to create a payment note.
Implementations
Sourceimpl PaymentNoteDescription
impl PaymentNoteDescription
Sourcepub fn new(
assets: Vec<Asset>,
sender_account_id: AccountId,
target_account_id: AccountId,
) -> PaymentNoteDescription
pub fn new( assets: Vec<Asset>, sender_account_id: AccountId, target_account_id: AccountId, ) -> PaymentNoteDescription
Creates a new PaymentNoteDescription.
Sourcepub fn with_reclaim_height(
self,
reclaim_height: BlockNumber,
) -> PaymentNoteDescription
pub fn with_reclaim_height( self, reclaim_height: BlockNumber, ) -> PaymentNoteDescription
Modifies the PaymentNoteDescription to set a reclaim height for payment note.
Sourcepub fn with_timelock_height(
self,
timelock_height: BlockNumber,
) -> PaymentNoteDescription
pub fn with_timelock_height( self, timelock_height: BlockNumber, ) -> PaymentNoteDescription
Modifies the PaymentNoteDescription to set a timelock height for payment note.
Sourcepub fn account_id(&self) -> AccountId
pub fn account_id(&self) -> AccountId
Returns the executor AccountId.
Sourcepub fn target_account_id(&self) -> AccountId
pub fn target_account_id(&self) -> AccountId
Returns the target AccountId.
Sourcepub fn reclaim_height(&self) -> Option<BlockNumber>
pub fn reclaim_height(&self) -> Option<BlockNumber>
Returns the reclaim height for the P2IDE note, if set.
Sourcepub fn timelock_height(&self) -> Option<BlockNumber>
pub fn timelock_height(&self) -> Option<BlockNumber>
Returns the timelock height for the P2IDE note, if set.