pub struct SwapTransactionData { /* private fields */ }Expand description
Contains information related to a swap transaction.
A swap transaction involves creating a SWAP note, which will carry the offered asset and which, when consumed, will create a payback note that carries the requested asset taken from the consumer account’s vault.
Implementations
Sourceimpl SwapTransactionData
impl SwapTransactionData
Sourcepub fn new(
sender_account_id: AccountId,
offered_asset: Asset,
requested_asset: Asset,
) -> SwapTransactionData
pub fn new( sender_account_id: AccountId, offered_asset: Asset, requested_asset: Asset, ) -> SwapTransactionData
Creates a new SwapTransactionData.
Sourcepub fn account_id(&self) -> AccountId
pub fn account_id(&self) -> AccountId
Returns the executor AccountId.
Sourcepub fn offered_asset(&self) -> Asset
pub fn offered_asset(&self) -> Asset
Returns the transaction offered Asset.
Sourcepub fn requested_asset(&self) -> Asset
pub fn requested_asset(&self) -> Asset
Returns the transaction requested Asset.