Module utils

Provides various utilities that are commonly used throughout the Miden client library.

Structs

LazyLock
A value which is initialized on the first access.

Enums

DeserializationError
Defines errors which can occur during deserialization.

Traits

ByteReader
Defines how primitive values are to be read from Self.
ByteWriter
Defines how primitive values are to be written into Self.
Deserializable
Defines how to deserialize Self from bytes.
Serializable
Defines how to serialize Self into bytes.

Functions

bytes_to_hex_string
Renders an array of bytes as hex into a String.

Type Aliases

RwLock
A reader-writer lock
RwLockReadGuard
RAII structure used to release the shared read access of a lock when dropped.
RwLockWriteGuard
RAII structure used to release the exclusive write access of a lock when dropped.