pub struct ClaimNote;Expand description
CLAIM (Bridge from AggLayer) note.
This note instructs the AggLayer bridge to validate a claim against its registered GERs and emit a corresponding MINT note for the AggLayer faucet. CLAIM notes are always public.
Implementations
Sourceimpl ClaimNote
impl ClaimNote
Sourcepub fn script() -> NoteScript
pub fn script() -> NoteScript
Returns the CLAIM (Bridge from AggLayer) note script.
Sourcepub fn script_root() -> NoteScriptRoot
pub fn script_root() -> NoteScriptRoot
Returns the CLAIM note script root.
Sourcepub fn create<R>(
storage: ClaimNoteStorage,
target_bridge_id: AccountId,
sender_account_id: AccountId,
rng: &mut R,
) -> Result<Note, NoteError>where
R: FeltRng,
pub fn create<R>(
storage: ClaimNoteStorage,
target_bridge_id: AccountId,
sender_account_id: AccountId,
rng: &mut R,
) -> Result<Note, NoteError>where
R: FeltRng,
Creates a CLAIM note — a note that instructs the bridge to validate a claim and create a MINT note for the AggLayer Faucet. CLAIM notes are always public.
Parameters
storage: The core storage for creating the CLAIM notetarget_bridge_id: The account ID of the bridge that should consume this note. Encoded as aNetworkAccountTargetattachment on the note metadata.sender_account_id: The account ID of the CLAIM note creatorrng: Random number generator for creating the CLAIM note serial number
Errors
Returns an error if note creation fails.