Constants
- ERR_
B2AGG_ DESTINATION_ NETWORK_ IS_ MIDEN - Error Message: “B2AGG note destination network ID must not be Miden’s AggLayer network ID”
- ERR_
B2AGG_ NOTE_ MUST_ BE_ PUBLIC - Error Message: “B2AGG note must be public”
- ERR_
B2AGG_ TARGET_ ACCOUNT_ MISMATCH - Error Message: “B2AGG note attachment target account does not match consuming account”
- ERR_
B2AGG_ UNEXPECTED_ NUMBER_ OF_ STORAGE_ ITEMS - Error Message: “B2AGG script expects exactly 6 note storage items”
- ERR_
B2AGG_ WRONG_ NUMBER_ OF_ ASSETS - Error Message: “B2AGG script requires exactly 1 note asset”
- ERR_
BRIDGE_ NOT_ MAINNET - Error Message: “mainnet flag must be 1 for a mainnet deposit”
- ERR_
BRIDGE_ NOT_ ROLLUP - Error Message: “mainnet flag must be 0 for a rollup deposit”
- ERR_
CLAIM_ ALREADY_ SPENT - Error Message: “claim note has already been spent”
- ERR_
CLAIM_ LEAF_ DESTINATION_ NETWORK_ MISMATCH - Error Message: “claim leaf destination network does not match Miden AggLayer network ID”
- ERR_
CLAIM_ TARGET_ ACCT_ MISMATCH - Error Message: “CLAIM note attachment target account does not match consuming account”
- ERR_
CONFIG_ AGG_ BRIDGE_ TARGET_ ACCOUNT_ MISMATCH - Error Message: “CONFIG_AGG_BRIDGE note attachment target account does not match consuming account”
- ERR_
CONFIG_ AGG_ BRIDGE_ UNEXPECTED_ STORAGE_ ITEMS - Error Message: “CONFIG_AGG_BRIDGE expects exactly 18 note storage items”
- ERR_
FAUCET_ NOT_ REGISTERED - Error Message: “faucet is not registered in the bridge’s faucet registry”
- ERR_
FELT_ OUT_ OF_ FIELD - Error Message: “combined u64 doesn’t fit in field”
- ERR_
GER_ ALREADY_ REGISTERED - Error Message: “GER is already registered in storage”
- ERR_
GER_ NOT_ FOUND - Error Message: “GER not found in storage”
- ERR_
INVALID_ LEAF_ TYPE - Error Message: “invalid leaf type: only asset claims (leafType=0) are supported”
- ERR_
LEADING_ BITS_ NON_ ZERO - Error Message: “leading bits of global index must be zero”
- ERR_
MAINNET_ FLAG_ INVALID - Error Message: “mainnet flag must be 0 or 1”
- ERR_
MSB_ NONZERO - Error Message: “most-significant 4 bytes must be zero for AccountId”
- ERR_
MTF_ LEAVES_ NUM_ EXCEED_ LIMIT - Error Message: “number of leaves in the MTF would exceed 4294967295 (2^32 - 1)”
- ERR_
NOT_ U32 - Error Message: “address limb is not u32”
- ERR_
REMAINDER_ TOO_ LARGE - Error Message: “remainder z must be < 10^s”
- ERR_
ROLLUP_ INDEX_ NON_ ZERO - Error Message: “rollup index must be zero for a mainnet deposit”
- ERR_
SCALE_ AMOUNT_ EXCEEDED_ LIMIT - Error Message: “maximum scaling factor is 18”
- ERR_
SENDER_ NOT_ BRIDGE_ ADMIN - Error Message: “note sender is not the bridge admin”
- ERR_
SENDER_ NOT_ GER_ MANAGER - Error Message: “note sender is not the global exit root manager”
- ERR_
SMT_ ROOT_ VERIFICATION_ FAILED - Error Message: “merkle proof verification failed: provided SMT root does not match the computed root”
- ERR_
SOURCE_ BRIDGE_ NETWORK_ OVERFLOW - Error Message: “source bridge network overflowed u32”
- ERR_
TOKEN_ NOT_ REGISTERED - Error Message: “(origin token address, origin network) pair is not registered in the bridge’s token registry”
- ERR_
UNDERFLOW - Error Message: “x < y*10^s (underflow detected)”
- ERR_
UPDATE_ GER_ TARGET_ ACCOUNT_ MISMATCH - Error Message: “UPDATE_GER note attachment target account does not match consuming account”
- ERR_
UPDATE_ GER_ UNEXPECTED_ NUMBER_ OF_ STORAGE_ ITEMS - Error Message: “UPDATE_GER script expects exactly 8 note storage items”
- ERR_
X_ TOO_ LARGE - Error Message: “the agglayer bridge in u256 value is larger than 2**128 and cannot be verifiably scaled to u64”
- ERR_
Y_ TOO_ LARGE - Error Message: “y exceeds max fungible token amount”