Available on crate feature
std only.Structs
- Client
Builder - A builder for constructing a Miden client.
Enums
- Store
Builder - Allows the
ClientBuilderto accept either an already built store instance or a factory for deferring the store instantiation.
Traits
- Builder
Authenticator - Marker trait to capture the bounds the builder requires for the authenticator type parameter
- Store
Factory - Trait for building a store instance.