ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder<AUTH> {
    pub store: Option<StoreBuilder>,
    /* private fields */
}
Available on crate feature std only.
A builder for constructing a Miden client.

This builder allows you to configure the various components required by the client, such as the RPC endpoint, store, RNG, and keystore. It is generic over the keystore type. By default, it uses FilesystemKeyStore.

Fields

store: Option<StoreBuilder>

An optional store provided by the user.

Implementations

Source

impl<AUTH> ClientBuilder<AUTH>

pub fn new() -> Self

Create a new ClientBuilder with default settings.

pub fn in_debug_mode(self, debug: DebugMode) -> Self

Enable or disable debug mode.

pub fn rpc(self, client: Arc<dyn NodeRpcClient>) -> Self

Sets a custom RPC client directly.

pub fn grpc_client(self, endpoint: &Endpoint, timeout_ms: Option<u64>) -> Self

Available on crate feature tonic only.

Sets a gRPC client from the endpoint and optional timeout.

pub fn store(self, store: Arc<dyn Store>) -> Self

Provide a store to be used by the client.

pub fn rng(self, rng: ClientRngBox) -> Self

Optionally provide a custom RNG.

pub fn authenticator(self, authenticator: Arc<AUTH>) -> Self

Optionally provide a custom authenticator instance.

pub fn max_block_number_delta(self, delta: u32) -> Self

Optionally set a maximum number of blocks that the client can be behind the network. By default, there’s no maximum.

pub fn tx_graceful_blocks(self, delta: Option<u32>) -> Self

Optionally set a maximum number of blocks to wait for a transaction to be confirmed. If None, there is no limit and transactions will be kept indefinitely. By default, the maximum is set to TX_GRACEFUL_BLOCKS.

pub fn filesystem_keystore(self, keystore_path: &str) -> Self

Required: Provide the keystore path as a string.

This stores the keystore path as a configuration option so that actual keystore initialization is deferred until build(). This avoids panicking during builder chaining.

pub fn note_transport(self, client: Arc<dyn NoteTransportClient>) -> Self

Sets a custom note transport client directly.

pub fn prover(self, prover: Arc<dyn TransactionProver + Send + Sync>) -> Self

Sets a custom transaction prover.

pub async fn build(self) -> Result<Client<AUTH>, ClientError>

Build and return the Client.

Errors
  • Returns an error if no RPC client or endpoint was provided.
  • Returns an error if the store cannot be instantiated.
  • Returns an error if the keystore is not specified or fails to initialize.