pub struct ClientBuilder<AUTH> {
pub store: Option<StoreBuilder>,
/* private fields */
}std only.Expand description
A builder for constructing a Miden client.
This builder allows you to configure the various components required by the client, such as the
RPC endpoint, store, RNG, and keystore. It is generic over the keystore type. By default, it
uses FilesystemKeyStore.
Fields
store: Option<StoreBuilder>An optional store provided by the user.
Implementations
Sourceimpl<AUTH> ClientBuilder<AUTH>where
AUTH: BuilderAuthenticator,
impl<AUTH> ClientBuilder<AUTH>where
AUTH: BuilderAuthenticator,
Sourcepub fn in_debug_mode(self, debug: DebugMode) -> Self
pub fn in_debug_mode(self, debug: DebugMode) -> Self
Enable or disable debug mode.
Sourcepub fn rpc(self, client: Arc<dyn NodeRpcClient>) -> Self
pub fn rpc(self, client: Arc<dyn NodeRpcClient>) -> Self
Sets a custom RPC client directly.
Sourcepub fn grpc_client(self, endpoint: &Endpoint, timeout_ms: Option<u64>) -> Self
Available on crate feature tonic only.
pub fn grpc_client(self, endpoint: &Endpoint, timeout_ms: Option<u64>) -> Self
tonic only.Sets a gRPC client from the endpoint and optional timeout.
Sourcepub fn rng(self, rng: ClientRngBox) -> Self
pub fn rng(self, rng: ClientRngBox) -> Self
Optionally provide a custom RNG.
Sourcepub fn authenticator(self, authenticator: Arc<AUTH>) -> Self
pub fn authenticator(self, authenticator: Arc<AUTH>) -> Self
Optionally provide a custom authenticator instance.
Sourcepub fn max_block_number_delta(self, delta: u32) -> Self
pub fn max_block_number_delta(self, delta: u32) -> Self
Optionally set a maximum number of blocks that the client can be behind the network. By default, there’s no maximum.
Sourcepub fn tx_graceful_blocks(self, delta: Option<u32>) -> Self
pub fn tx_graceful_blocks(self, delta: Option<u32>) -> Self
Optionally set a maximum number of blocks to wait for a transaction to be confirmed. If
None, there is no limit and transactions will be kept indefinitely.
By default, the maximum is set to TX_GRACEFUL_BLOCKS.
Sourcepub fn filesystem_keystore(self, keystore_path: &str) -> Self
pub fn filesystem_keystore(self, keystore_path: &str) -> Self
Required: Provide the keystore path as a string.
This stores the keystore path as a configuration option so that actual keystore
initialization is deferred until build(). This avoids panicking during builder chaining.
Sourcepub fn note_transport(self, client: Arc<dyn NoteTransportClient>) -> Self
pub fn note_transport(self, client: Arc<dyn NoteTransportClient>) -> Self
Sets a custom note transport client directly.