pub struct SwapNoteStorage { /* private fields */ }Expand description
Canonical storage representation for a SWAP note.
Contains the payback note configuration and the requested asset that the swap creator wants to receive in exchange for the offered asset contained in the note’s vault.
Implementations
Sourceimpl SwapNoteStorage
impl SwapNoteStorage
Sourcepub fn new(
sender: AccountId,
requested_asset: Asset,
payback_note_type: NoteType,
payback_serial_number: Word,
) -> SwapNoteStorage
pub fn new( sender: AccountId, requested_asset: Asset, payback_note_type: NoteType, payback_serial_number: Word, ) -> SwapNoteStorage
Creates new SWAP note storage with the specified parameters.
Sourcepub fn from_parts(
payback_note_type: NoteType,
payback_tag: NoteTag,
requested_asset: Asset,
payback_recipient_digest: Word,
) -> SwapNoteStorage
pub fn from_parts( payback_note_type: NoteType, payback_tag: NoteTag, requested_asset: Asset, payback_recipient_digest: Word, ) -> SwapNoteStorage
Creates a SwapNoteStorage from raw parts.
Sourcepub fn payback_note_type(&self) -> NoteType
pub fn payback_note_type(&self) -> NoteType
Returns the payback note type.
Sourcepub fn payback_tag(&self) -> NoteTag
pub fn payback_tag(&self) -> NoteTag
Returns the payback note tag.
Sourcepub fn requested_asset(&self) -> Asset
pub fn requested_asset(&self) -> Asset
Returns the requested asset.
Sourcepub fn payback_recipient_digest(&self) -> Word
pub fn payback_recipient_digest(&self) -> Word
Returns the payback recipient digest.
Sourcepub fn into_recipient(self, serial_num: Word) -> NoteRecipient
pub fn into_recipient(self, serial_num: Word) -> NoteRecipient
Consumes the storage and returns a SWAP NoteRecipient with the provided serial number.
Notes created with this recipient will be SWAP notes whose storage encodes the payback
configuration and the requested asset stored in this SwapNoteStorage.