GrpcNoteTransportClient

Struct GrpcNoteTransportClient 

pub struct GrpcNoteTransportClient { /* private fields */ }
Available on crate feature tonic only.
gRPC client

Implementations

Source

impl GrpcNoteTransportClient

pub async fn connect( endpoint: String, timeout_ms: u64, ) -> Result<Self, NoteTransportError>

Available on non-WebAssembly only.

gRPC client constructor

pub async fn send_note( &self, header: NoteHeader, details: Vec<u8>, ) -> Result<(), NoteTransportError>

Pushes a note to the note transport network.

While the note header goes in plaintext, the provided note details can be encrypted.

pub async fn fetch_notes( &self, tags: &[NoteTag], cursor: NoteTransportCursor, ) -> Result<(Vec<NoteInfo>, NoteTransportCursor), NoteTransportError>

Downloads notes for given tags from the note transport network.

Returns notes labeled after the provided cursor (pagination), and an updated cursor.

pub async fn stream_notes( &self, tag: NoteTag, cursor: NoteTransportCursor, ) -> Result<NoteStreamAdapter, NoteTransportError>

Stream notes from the note transport network.

Subscribes to a given tag. New notes are received periodically.

pub async fn health_check(&mut self) -> Result<(), NoteTransportError>

gRPC-standardized server health-check.

Checks if the note transport node and respective gRPC services are serving requests. Currently the grPC server operates only one service labelled MidenNoteTransport.