Available on crate features
testing and std only.Re-exports
pub use crate::keystore::FilesystemKeyStore;
Constants
- ACCOUNT_
ID_ REGULAR - MINT_
AMOUNT - RECALL_
HEIGHT_ DELTA - Constant that represents the number of blocks until the p2id can be recalled. If this value is too low, some tests might fail due to expected recall failures not happening.
- TRANSFER_
AMOUNT
Functions
- assert_
account_ has_ single_ asset - Asserts that the account has a single asset with the expected amount.
- assert_
note_ cannot_ be_ consumed_ twice - Tries to consume the note and asserts that the expected error is returned.
- consume_
notes - Executes a transaction that consumes the provided notes and returns the transaction ID. This assumes the notes contain assets.
- create_
test_ store_ path - execute_
failing_ tx - Executes a transaction and asserts that it fails with the expected error.
- execute_
tx_ and_ consume_ output_ notes - Executes a transaction and consumes the resulting unauthenticated notes immediately without waiting for the first transaction to be committed.
- execute_
tx_ and_ sync - Executes a transaction and waits for it to be committed.
- insert_
account_ with_ custom_ component - Creates and inserts an account with custom code as a component into the client.
- insert_
new_ fungible_ faucet - Inserts a new fungible faucet account into the client and into the keystore.
- insert_
new_ wallet - Inserts a new wallet account into the client and into the keystore.
- insert_
new_ wallet_ with_ seed - Inserts a new wallet account built with the provided seed into the client and into the keystore.
- mint_
and_ consume - Mints assets for the target account and consumes them immediately without waiting for the first transaction to be committed.
- mint_
multiple_ fungible_ asset - Creates a transaction request that mints assets for each
target_idaccount. - mint_
note - Mints a note from
faucet_account_idforbasic_account_idand returns the executed transaction ID and the note withMINT_AMOUNTunits of the corresponding fungible asset. - setup_
two_ wallets_ and_ faucet - Sets up a basic client and returns two basic accounts and a faucet account (in that order).
- setup_
wallet_ and_ faucet - Sets up a basic client and returns a basic account and a faucet account.
- wait_
for_ blocks - Syncs until
amount_of_blockshave been created onchain compared to client’s sync height - wait_
for_ blocks_ no_ sync - Idles until
amount_of_blockshave been created onchain compared to client’s sync height without advancing the client’s sync height - wait_
for_ node - Waits for node to be running.
- wait_
for_ tx - Syncs the client and waits for the transaction to be committed.