pub struct MockRpcApi {
pub mock_chain: Arc<RwLock<MockChain>>,
/* private fields */
}testing only.Expand description
Mock RPC API
This struct implements the RPC API used by the client to communicate with the node. It simulates most of the functionality of the actual node, with some small differences:
- It uses a
MockChainto simulate the blockchain state. - Blocks are not automatically created after time passes, but rather new blocks are created when
calling the
prove_blockmethod. - Network account and transactions aren’t supported in the current version.
- Account update block numbers aren’t tracked, so any endpoint that returns when certain account updates were made will return the chain tip block number instead.
Fields
mock_chain: Arc<RwLock<MockChain>>Implementations
Sourceimpl MockRpcApi
impl MockRpcApi
Sourcepub fn new(mock_chain: MockChain) -> Self
pub fn new(mock_chain: MockChain) -> Self
Creates a new MockRpcApi instance with the state of the provided MockChain.
Sourcepub fn get_chain_tip_block_num(&self) -> BlockNumber
pub fn get_chain_tip_block_num(&self) -> BlockNumber
Returns the chain tip block number.
Sourcepub fn prove_block(&self)
pub fn prove_block(&self)
Advances the mock chain by proving the next block, committing all pending objects to the chain in the process.
pub fn get_available_notes(&self) -> Vec<MockChainNote>
pub fn get_public_available_notes(&self) -> Vec<MockChainNote>
pub fn get_private_available_notes(&self) -> Vec<MockChainNote>
pub fn advance_blocks(&self, num_blocks: u32)