pub trait MockAccountCodeExt {
// Provided methods
fn mock_account_library() -> Library { ... }
fn mock_faucet_library() -> Library { ... }
}Available on crate feature
testing only.Expand description
Extension trait for AccountCode to access the mock libraries.
Provided Methods
Sourcefn mock_account_library() -> Library
fn mock_account_library() -> Library
Returns the Library of the mock account under the mock::account namespace.
This account interface wraps most account kernel APIs for testing purposes.
Sourcefn mock_faucet_library() -> Library
fn mock_faucet_library() -> Library
Returns the Library of the mock faucet under the mock::faucet namespace.
This account interface wraps most faucet kernel APIs for testing purposes.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.