pub struct PswapTransactionData { /* private fields */ }Expand description
Contains information related to a partial swap (PSWAP) transaction.
A PSWAP transaction involves creating a PSWAP note that carries the offered fungible asset and, when consumed (filled), produces a payback note carrying the requested fungible asset taken from the filler’s vault. Both legs are restricted to fungible assets so that fills can be denominated in arbitrary amounts.
Implementations
Sourceimpl PswapTransactionData
impl PswapTransactionData
Sourcepub fn new(
creator_account_id: AccountId,
offered_asset: FungibleAsset,
requested_asset: FungibleAsset,
) -> PswapTransactionData
pub fn new( creator_account_id: AccountId, offered_asset: FungibleAsset, requested_asset: FungibleAsset, ) -> PswapTransactionData
Creates a new PswapTransactionData.
Sourcepub fn creator_account_id(&self) -> AccountId
pub fn creator_account_id(&self) -> AccountId
Returns the creator AccountId.
Sourcepub fn offered_asset(&self) -> FungibleAsset
pub fn offered_asset(&self) -> FungibleAsset
Returns the offered FungibleAsset.
Sourcepub fn requested_asset(&self) -> FungibleAsset
pub fn requested_asset(&self) -> FungibleAsset
Returns the requested FungibleAsset.