Provides various utilities that are commonly used throughout the Miden client library.
Structs
- Lazy
Lock - A value which is initialized on the first access.
Enums
- Deserialization
Error - Defines errors which can occur during deserialization.
Traits
- Byte
Reader - Defines how primitive values are to be read from
Self. - Byte
Writer - Defines how primitive values are to be written into
Self. - Deserializable
- Defines how to deserialize
Selffrom bytes. - Serializable
- Defines how to serialize
Selfinto bytes.
Functions
- bytes_
to_ hex_ string - Renders an array of bytes as hex into a String.
Type Aliases
- RwLock
- A reader-writer lock
- RwLock
Read Guard - RAII structure used to release the shared read access of a lock when dropped.
- RwLock
Write Guard - RAII structure used to release the exclusive write access of a lock when dropped.